import QtQuick 1.0
import "SolitaireCard.js" as SolitaireCardCode

Flipable  {
    signal wasClicked(variant data)
    signal cardReleased(variant data)
    signal cardPositionChanged(variant data)
    signal cardMoveMoveAnimationStateChanged(variant data)
    //signal wasChanged
    property int cardNumber: 1
    // 1...52
    // clubs: 1...13
    // diamonds: 14...26
    // hearts: 27...39
    // spades: 40...52

    property int stack: -1
    property int stackIndex: 0
    property bool faceUp: false

    property bool selectable: false
    property bool selected: false
    property bool draggable: false
    property bool cardMoveAnimation: true
    property bool cardFlipAnimation: false
    property bool cardClicked: false

    property bool applicationActive: solitaire.applicationActive

    property int angle: 0

    id: ownCard
    // TODO: this is not very nice to hardcode this.
    width: phonemodel == "meego" ? 60: 46
    height: phonemodel == "meego" ? 72: 55
    scale: cardClicked || !cardMoveAnimation ? 1.5 : 1.0

/*    onCardMoveAnimationChanged: {
        if ( cardMoveAnimation ) {
            console.log("changing card " + cardNumber + " transition");
            ownCard.transitions: [Transition {
                NumberAnimation {
                    properties: "angle"
                    duration: 500
                }
            }];
        }


    }
*/

    //onWasClicked: cardSelected = !cardSelected

    // 1 = clubs
    // 2 = diamonds
    // 3 = hearts
    // 4 = spades
/*    function cardSuite() {
        var suite = 1;
        if ( cardNumber <= 13 ) {
            suite = 1;
        } else if ( cardNumber <= 26 ) {
            suite = 2;
        } else if ( cardNumber <= 39 ) {
            suite = 3;
        } else {
            suite = 4;
        }
    }
*/
    onCardFlipAnimationChanged : {
        flipAnimationId.complete()
    }

    ImageLocations {
        id: imagesId
    }

    function cardImageFromNumber(aCardNumber)
    {

        var name = imagesId.imgCardLocation
        var tempCardNumber = ((aCardNumber-1)%52)+1;
        if ( tempCardNumber <= 13 ) {
            name += imagesId.imgCardClub
        } else if ( tempCardNumber <= 26 ) {
            name += imagesId.imgCardDiamond
        } else if ( tempCardNumber <= 39 ) {
            name += imagesId.imgCardHeart
        } else {
            name += imagesId.imgCardSpade
        }
        var number = (tempCardNumber-1) % 13
        switch (number)
        {
        case 0:
            name+=imagesId.imgCardAce
            break;
        case 10:
            name+=imagesId.imgCardJack
            break;
        case 11:
            name+=imagesId.imgCardQueen
            break;
        case 12:
            name+=imagesId.imgCardKing
            break;
        default:
            name+=(number+1)
            break;
        }
        name += imagesId.imgCardType
//        console.log("OwnCard:" + aCardNumber + " " + name);
        return name
    }

    // bug in qt fw, incoming call does not clear mouse area

    onApplicationActiveChanged: {
        if (!applicationActive && cardClicked) {
            cardClicked = false
            cardReleased({cardNumber: cardNumber})
            // drop at illegal place, so returns to previous state
            solitairerunner.cardReleased(cardNumber, -1, -1)
        }
    }


    onStackChanged: {
        if (stack == 0) {

        } else {
            ownCard.z = stackIndex + stack*52
        }
//        console.log("stack changed " + cardImageFromNumber(cardNumber) + " z: " + ownCard.z)
//        if (stack == 0) {
//            ownCard.parent = dragLayer
//        }
    }

    onStackIndexChanged: {
        ownCard.z = stackIndex + stack*52
//        console.log("stackindex changed " + cardImageFromNumber(cardNumber) + " " +stackIndex + " z: " + ownCard.z)
    }

    front: Image {
        id: cardBitmapId
        anchors.fill: parent
        source: cardImageFromNumber(cardNumber)
    }
    back: Image {
        anchors.fill: parent
        source: imagesId.imgCardLocation + imagesId.imgCardBg
    }

    Rectangle {
        id: selectionRect
        anchors.fill: parent
        color: "black"
        opacity: 0.0
    }

    transform: Rotation {
        origin.x: ownCard.width/2
        origin.y: ownCard.height/2
        axis.x: 1; axis.y: 0; axis.z: 0     // rotate around y-axis
        angle: ownCard.angle
    }

    MouseArea {
        anchors.fill: parent
        enabled: !tableId.cardTouchDisabled && !cardMoveXAnimation.running && faceUp
        drag.target: ownCard
        drag.axis: Drag.XandYAxis
        drag.minimumX: draggable ? 0 : ownCard.x
        drag.maximumX: draggable ? tableId.x + tableId.width - ownCard.width : ownCard.x
        drag.minimumY: draggable ? 0 : ownCard.y
        drag.maximumY: draggable ? tableId.y + tableId.height - ownCard.height : ownCard.y
        onReleased: {
//            console.log("card " + cardNumber + " released")
            if (draggable) {
                cardClicked = false
                cardReleased({cardNumber: cardNumber})
                solitairerunner.cardReleased(cardNumber, ownCard.x+ownCard.width/2, ownCard.y+ownCard.height/2)
            }
        }
        onPositionChanged: {
            if (draggable) {
                cardClicked = true
//                console.log("card pos changed " + cardNumber + " (" + ownCard.x + "," + ownCard.y + ")")
                cardPositionChanged({cardNumber: cardNumber})
                solitairerunner.cardMoved(cardNumber, ownCard.x, ownCard.y)
            }
        }
        onClicked: {
            if (selectable) {
                //cardClicked({cardNumber: cardNumber})
                solitairerunner.cardClicked(cardNumber)
            }
        }
        onPressed: {
            if (draggable) {
                cardClicked = true
//                console.log("card pressed " + cardNumber + " (" + ownCard.x + "," + ownCard.y + ")")
                cardPositionChanged({cardNumber: cardNumber, cardX: ownCard.x, cardY: ownCard.y})
                solitairerunner.cardMoved(cardNumber, ownCard.x, ownCard.y)
            }
        }
    }


    Behavior on x {
        enabled: cardMoveAnimation && solitairelayout.moveAnimation
        PropertyAnimation {
            id: cardMoveXAnimation
            duration: solitairelayout.moveAnimationTime
            onRunningChanged: {
                if (!running) {
                    ownCard.parent = cardLayer
                    //solitairerunner.cardAnimationFinished(cardNumber)
                }
                cardMoveMoveAnimationStateChanged({state: running})
            }
        }
    }
    Behavior on y {
        enabled: cardMoveAnimation && solitairelayout.moveAnimation
        PropertyAnimation {
            duration: solitairelayout.moveAnimationTime
        }
    }

    Behavior on scale {
        PropertyAnimation {
            duration: solitairelayout.moveAnimationTime
        }
    }

    Behavior on rotation {
        enabled: solitairelayout.flipAnimation
        NumberAnimation {
            duration: solitairelayout.moveAnimationTime
        }
    }

    Behavior on angle {
        enabled: cardFlipAnimation && solitairelayout.flipAnimation
        NumberAnimation {
            id: flipAnimationId
            duration: solitairelayout.flipAnimationTime
        }
    }


    states: [
        State {
            name: "faceUp"
            when: !selected && faceUp
            PropertyChanges { target: ownCard; angle: 0 }
        },
        State {
            name: "CardSelectedState"
            when: selected && faceUp
            PropertyChanges { target: selectionRect; opacity: 0.4 }
        },
        State {
           name: "back"
           PropertyChanges { target: ownCard; angle: 180 }
           when: !faceUp
       }
    ]


    Component.onCompleted: {
        // temporary solution before layout solved
        solitairelayout.cardWidth = width
        solitairelayout.cardGapWidth = width + 4
        solitairelayout.cardHeight = height
        solitairelayout.cardGapHeight = height + 10
        }
}
