import QtQuick 1.0

Image {

    property int gameState: solitairerunner.state

    onWidthChanged: {
        solitairelayout.tableWidth = width
    }

    onHeightChanged: {
        solitairelayout.tableHeight = height
    }



    onGameStateChanged: {
        if (gameState == 6 || gameState == 7) {
            gameEndTimerId.running = true
        } else {
            gameEndTimerId.running = false
        }
    }


    ImageLocations {
        id: imagesId
    }
    source: width > height ? imagesId.imgBgLandscape : imagesId.imgBgPortrait

    SolitaireTable {
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: newGameButtonId.top

        MouseArea {
            id: tableuMouseAreaId
            enabled: gameState == 6 || gameState == 7
            anchors.fill: parent
            onClicked: {
                gameEndTimerId.running = true
            }
        }
    }

    Image {
        id: newGameButtonId
        x: solitairelayout.newGameButtonX >= 0 ? solitairelayout.newGameButtonX : parent.width - width
        y: solitairelayout.newGameButtonY >= 0 ? solitairelayout.newGameButtonY : parent.height - height
        source: newGameButtonAreaId.pressed ? imagesId.imgButtonNewGamePressed : imagesId.imgButtonNewGame
        MouseArea {
            id: newGameButtonAreaId
            anchors.fill: parent
            onClicked: {
                solitairerunner.newGameButtonPressed()
            }
        }
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
    }

    Image {
        id: closeGameButtonId
        x: solitairelayout.backButtonX >= 0 ? solitairelayout.backButtonX : 0
        y: solitairelayout.backButtonY >= 0 ? solitairelayout.backButtonY : parent.height - height
        source: closeGameButtonAreaId.pressed ? imagesId.imgButtonBackPressed : imagesId.imgButtonBack
        MouseArea {
            id: closeGameButtonAreaId
            anchors.fill: parent
            onClicked: {
                onClicked: solitairerunner.quitGame()
            }
        }
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
    }


    Timer {
        id: gameEndTimerId
        interval: solitairelayout.splashAnimationTime
        running: false
        repeat: false

     }

    Item {
        id: gameEndSplashId
        visible: gameEndTimerId.running
        anchors.fill: parent

        Image {
            source: gameState == 6 ? imagesId.imgYouWon : imagesId.imgNoMoreMoves
            anchors.centerIn: parent
        }
    }

    Item {
        id: undoButton
        x: solitairelayout.undoButtonX >= 0 ? solitairelayout.undoButtonX : (solitairelayout.leftHanded ? closeGameButtonId.x + closeGameButtonId.width : newGameButtonId.x - width)
        y: solitairelayout.undoButtonY >= 0 ? solitairelayout.undoButtonY : parent.height-height
        width: 80
        height: 70
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        MouseArea {
            id: undoButtonAreaId
            anchors.fill: parent
            enabled: solitairerunner.undoAvailable
            onClicked: {
                solitairerunner.undoButtonPressed()
            }
        }
        Image {
//            scale: 1.1
            anchors.centerIn: parent
            source: solitairerunner.undoAvailable ? imagesId.imgButtonUndo : imagesId.imgButtonUndoDimmed
        }
    }

    Item {
        id: helpButton
        x: solitairelayout.helpButtonX >= 0 ? solitairelayout.helpButtonX : (solitairelayout.leftHanded ? newGameButtonId.x - width : closeGameButtonId.x + closeGameButtonId.width + 5)
        y: solitairelayout.helpButtonY >= 0 ? solitairelayout.helpButtonY : parent.height-height
        width: 70
        height: 70
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        MouseArea {
            id: helpButtonAreaId
            anchors.fill: parent
            onClicked: {
                helpId.setFlickableAtTop()
                helpId.visible = true
            }
        }
        Image {
            anchors.centerIn: parent
            source: imagesId.imgButtonHelp
        }
    }

    HelpView {
        id: helpId
        visible: false

        onCloseHelpPressed: {
            helpId.visible = false
        }
    }

/*
    states: [
        State {
            name: "gameOngoing"
            when: gameState != 6 && gameState != 7
            PropertyChanges { target: gameEndSplashId; opacity: 0 }
        },
        State {
            name: "gameEndSplash"
            when: gameState == 6 || gameState == 7
            PropertyChanges { target: gameEndSplashId; opacity: 1 }
        }
    ]
*/


}
