import QtQuick 1.0

Item {
    id: mainViewId
    property bool landscape: width > height

    //border.width: 3

    ImageLocations {
        id: imagesId
    }
    UiStrings {
        id: uiStringsId
    }

    Image {
        anchors.fill: parent
        source: mainViewId.width > mainViewId.height ? imagesId.imgBgLandscape : imagesId.imgBgPortrait
    }

    SolitaireListView {
        id: listViewId
        anchors.topMargin: 7
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: solitairefree ? fullVersionAdId.top : closeGameButtonId.top
        anchors.bottomMargin: 5
        visible: !solitaire.gameActive
        onItemSelected: {
            solitaire.launchGame(game)
        }
    }

    SolitaireGameView {
        id: gameViewId
        anchors.fill: parent
        visible: solitaire.gameActive
    }

    Item {
        id: fullVersionAdId
        visible: solitairefree && listViewId.visible
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: closeGameButtonId.top
        height: 104
        anchors.leftMargin: 10
        anchors.rightMargin: 10
        anchors.bottomMargin: 10
        anchors.topMargin: 1


        Image {
            id: goButtonId
            anchors.centerIn: parent
            source: imagesId.imgGetFullVersionAdButtonUndoDimmed
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                Qt.openUrlExternally(uiStringsId.txtSolitaireGameLoadFullVersionUrl)
            }

        }
    }

    Image {
        id: closeGameButtonId
        visible: listViewId.visible
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        source: closeGameButtonAreaId.pressed ? imagesId.imgButtonQuitPressed : imagesId.imgButtonQuit
        MouseArea {
            id: closeGameButtonAreaId
            anchors.fill: parent
            onClicked: {
                Qt.quit()
            }
        }
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
    }

    Image {
        id: gameInfoButtonId
        visible: listViewId.visible
        anchors.bottom: parent.bottom
        anchors.right: parent.right
//        width: closeGameButtonId.width
//        height: closeGameButtonId.height
        source: buttonAreaId.pressed ? imagesId.imgButtonAbout : imagesId.imgButtonAbout
        MouseArea {
            id: buttonAreaId
            anchors.fill: parent

            onClicked: {
                infoId.visible = true
            }
        }
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
    }

    Image {
        id: directionButtonId
        visible: listViewId.visible
//        anchors.top: gameInfoButtonId.top
        anchors.bottom: parent.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottomMargin: 5
        source: solitairelayout.leftHanded ? imagesId.imgButtonLeftHand : imagesId.imgButtonRightHand
        MouseArea {
            anchors.fill: parent

            onClicked: {
                solitairelayout.leftHanded = !solitairelayout.leftHanded
            }
        }
        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
    }


    InfoView {
        id: infoId
        visible: false

        onCloseInfoViewPressed: {
            infoId.visible = false
        }
    }



    Timer {
        id: splashTimeId
        interval: solitairelayout.splashAnimationTime
        running: true
        repeat: false
     }

    Item {
        id: splashId
        anchors.fill: parent
        visible: splashTimeId.running

        // eat all the presses during the start image
        MouseArea {
            anchors.fill: parent
        }

        Image {
            source: mainViewId.width < mainViewId.height ? imagesId.imgSplashPortrait : imagesId.imgSplashLandscape
            anchors.fill: parent
        }
        Text {
            id: versionId
            text: solitaireVersion
            color: uiStringsId.txtColor
            font.pixelSize: 18
            anchors.rightMargin: 10
            anchors.bottomMargin: 6
            anchors.right: parent.right
            anchors.bottom: copyrightId.top
            MouseArea {
                onPressed: {

                }
            }
        }
        Text {
            id: copyrightId
            text: copyrightText
            color: uiStringsId.txtColor
            font.pixelSize: 12
            anchors.rightMargin: 10
            anchors.bottomMargin: 6
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            MouseArea {
                onPressed: {

                }
            }
        }
    }

}
