import QtQuick 1.0
import "SolitaireCard.js" as SolitaireCards
import "SolitaireCardStack.js" as SolitaireCardStack
import "games"

Item {
    property string statusText: solitairerunner.statusText

    property bool draggingCards: solitairehelper.draggingCards
    property bool undoingCards: solitairehelper.undoingCards

    property bool cardTouchDisabled: false
    property bool portrait: height > width
    property string currentGame: solitairerunner.currentGameId

    function layoutGame() {
        if (currentGame == "acesup") {
            acesUpId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "canfield") {
            canfieldId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "capturedqueens") {
            capturedQueensId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "corners") {
            cornersId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "kingofhearts") {
            kingOfHeartsId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "klondike" || currentGame == "klondikedrawone") {
            klondikeId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "napoleonseagle") {
            napoleonsEagleId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "napoleonsgrave") {
            napoleonsGraveId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "pairs") {
            pairsId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "portraitseven") {
            portraitSevenId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "pyramid") {
            pyramidId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "redandblack") {
            redAndBlackId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "testofpatience") {
            testOfPatienceId.layoutStacks(SolitaireCardStack.cardStacks())
        } else if (currentGame == "visitors") {
            visitorsId.layoutStacks(SolitaireCardStack.cardStacks())
        } else {
            solitairelayout.setDefaultDropStack(-1)
        }

    }

/*    onPortraitChanged: {
        layoutGame()
        solitairelayout.portrait = portrait
    }
*/
    onHeightChanged: {
        layoutGame()
        solitairelayout.portrait = portrait
    }

    onWidthChanged: {
        layoutGame()
        solitairelayout.portrait = portrait
    }

    onCurrentGameChanged: {
        layoutGame()
    }

    id: tableId

    function cardAnimationStateChanged(data) {
        cardTouchDisabled = data.state
    }

    function cardDrop(data) {
        var cardCount = solitairehelper.draggingCardsCount()
        var i=0;
        while (i<cardCount) {
            var childCard = SolitaireCards.getCard(solitairehelper.draggingCard(i))
            childCard.cardMoveAnimation=true
            i = i+1
        }
    }

    function cardMoved(data) {
        if (draggingCards) {
            var cardObject = SolitaireCards.getCard(data.cardNumber)
            var cardCount = solitairehelper.draggingCardsCount()
            var cascadeType = solitairehelper.draggingStackCascadeType()
            var i=1;
            var pos = solitairelayout.cascadeSize
            while (i<cardCount) {
                var childCard = SolitaireCards.getCard(solitairehelper.draggingCard(i))
                if (cascadeType === 2) {
                    childCard.x = cardObject.x+pos
                    childCard.y = cardObject.y
                } else if (cascadeType === 4) {
                    childCard.x = cardObject.x-pos
                    childCard.y = cardObject.y

                } else {
                    childCard.x = cardObject.x
                    childCard.y = cardObject.y+pos
                }
                pos = pos + solitairelayout.cascadeSize
                i = i+1
            }
        }
    }


    onDraggingCardsChanged: {
//        console.log("Dragging changed "+draggingCards)
        if (draggingCards) {
            var cardCount = solitairehelper.draggingCardsCount()
            var i=0;
            while (i<cardCount) {
                var childCard = SolitaireCards.getCard(solitairehelper.draggingCard(i))
                if (!childCard.selectable) {
                    childCard.cardMoveAnimation=false
                }
                childCard.parent=dragLayer
                childCard.z = i
                i = i+1
            }

        }
    }
    onUndoingCardsChanged: {
        if (undoingCards) {
            var cardCount = solitairehelper.undoingCardsCount()
//            console.log("undoing changed " + cardCount)
            var i=0;
            while (i<cardCount) {
                var childCard = SolitaireCards.getCard(solitairehelper.undoingCard(i))
                childCard.parent=dragLayer
                childCard.z = i
                i = i+1
            }
        }
    }

    Text {
        id: statusTextId
        x: solitairelayout.statusTextX
        y: solitairelayout.statusTextY
        color: uiStringsId.stackTxtColor1
        font.pixelSize: 18
/*        Behavior on x {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }
        Behavior on y {
            PropertyAnimation {
                duration: solitairelayout.moveAnimationTime
            }
        }*/

        text: statusText
        visible: statusText.length>0
    }

    Item {
        anchors.fill: parent
        id: stackLayer
    }

    Item{
        id: cardLayer
    }

    Item{
        id: dragLayer
        anchors.fill: parent
    }

    AcesUp {
        id: acesUpId
    }

    Canfield {
        id: canfieldId
    }

    CapturedQueens {
        id: capturedQueensId
    }

    Corners {
        id: cornersId
    }

    KingOfHearts {
        id: kingOfHeartsId
    }

    Klondike {
        id: klondikeId
    }

    NapoleonsEagle {
        id: napoleonsEagleId
    }

    NapoleonsGrave {
        id: napoleonsGraveId
    }

    Pairs {
        id: pairsId
    }

    PortraitSeven {
        id: portraitSevenId
    }

    Pyramid {
        id: pyramidId
    }

    RedAndBlack {
        id: redAndBlackId
    }

    TestOfPatience {
        id: testOfPatienceId
    }

    Visitors {
        id: visitorsId
    }

/*
    states: [
        State {
            name: "empty"
            when: currentGame == ""
            PropertyChanges { target: klondikeId; visible: false }
            PropertyChanges { target: acesUpId; visible: false }
        },
        State {
            name: "klondike"
            when: currentGame == "klondike"
            PropertyChanges { target: klondikeId; visible: true }
            PropertyChanges { target: acesUpId; visible: false }
        },
        State {
            name: "acesup"
            when: currentGame == "acesup"
            PropertyChanges { target: klondikeId; visible: false }
            PropertyChanges { target: acesUpId; visible: true }
        }
    ]
*/
    Component.onCompleted: {
        SolitaireCards.createCards();
        // this creates quite many stacks, even not needed. TODO: create only when needed.
        SolitaireCardStack.createCardStacks();
        }
}
