import QtQuick 1.0

Item {
    anchors.fill: parent

    property bool portrait: height > width
    property int layoutState: portrait ? (solitairelayout.leftHanded ? 0 : 1) : (solitairelayout.leftHanded ? 2 : 3)
    // 0: portrait left to right
    // 1: portrait right to left
    // 2: landscape left to right
    // 3: landscape right to left

    function oneStack(stack, x, y, cascade, showEmptyStack){
        stack.visible = true
        stack.showStack = showEmptyStack
        stack.x = x
        stack.y = y
        stack.cascadeType = cascade
    }

    function layoutStacks(stacks) {
        var gapX = solitairelayout.cardGapWidth;
        var gapY = solitairelayout.cardGapHeight;
        var faceUpCascadeSize = 25;

        var baseTop = 10;
        var baseLeft = Math.floor((width-4*gapX)/2);

        var handLeft = Math.floor((width-6*gapX)/2);

        var tableTop = Math.floor(solitairelayout.cardHeight*faceUpCascadeSize/100)*13+2*gapY;
        var tableLeft = handLeft + 2*gapX

        var handTop = tableTop + gapY;

        switch (layoutState) {
        default:
        case 0:
            // handled by default values
            break
        case 1:
            handLeft = handLeft+5*gapX
            tableLeft = handLeft - 5*gapX
            break
        case 2:
            tableTop = 10;
            tableLeft = Math.floor((width-11*gapX)/2) + 2*gapX;
            baseTop = tableTop;
            baseLeft = tableLeft + 5*gapX;

            handTop = tableTop + gapY;
            handLeft = tableLeft - 2*gapX;

            faceUpCascadeSize = 20;
            break
        case 3:
            tableTop = 10;
            tableLeft = Math.floor((width-11*gapX)/2) + 5*gapX;
            baseTop = tableTop;
            baseLeft = tableLeft - 5*gapX;

            handTop = tableTop + gapY;
            handLeft = tableLeft + 5*gapX;

            faceUpCascadeSize = 20;
            break
        }

        var stackCounter = 1
        oneStack(stacks[stackCounter], handLeft, handTop+gapY, 0, true)

        stackCounter++
        oneStack(stacks[stackCounter], handLeft, handTop, solitairelayout.leftHanded ? 3 : 5, true)

        // extra table stack
        stackCounter++
        oneStack(stacks[stackCounter], handLeft, tableTop, 0, true)

        // table stacks
        for (var i=0; i<4; ++i) {
            stackCounter++
            oneStack(stacks[stackCounter], tableLeft + i*gapX, tableTop, 1, true)
        }

        // base stacks
        for (var i=0; i<4; ++i) {
            stackCounter++
            oneStack(stacks[stackCounter], baseLeft + i*gapX, baseTop, 1, true)
        }

        solitairelayout.stackCount = stackCounter+1

        stacks[0].visible = false
        // hide all the rest
        for (var i=stackCounter+1; i<52; ++i) {
            stacks[i].visible = false
            stacks[i].showStack = false
        }

        solitairelayout.setCascadeSizeInPercent(faceUpCascadeSize)
        solitairelayout.setFaceDownCascadeSizeInPercent(faceUpCascadeSize)

    }
}
