// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Item {
    anchors.fill: parent

    property bool portrait: height > width
    property int layoutState: portrait ? (solitairelayout.leftHanded ? 0 : 1) : (solitairelayout.leftHanded ? 2 : 3)
    // 0: portrait left to right
    // 1: portrait right to left
    // 2: landscape left to right
    // 3: landscape right to left

    function oneStack(stack, x, y, cascade, showEmptyStack){
        stack.visible = true
        stack.showStack = showEmptyStack
        stack.x = x
        stack.y = y
        stack.cascadeType = cascade
    }


    function layoutStacks(stacks) {

        var gapX = solitairelayout.cardGapWidth;
        var gapY = solitairelayout.cardGapHeight;

        var tableTop = 40
        var tableLeft = 30
        var baseTop = tableTop + 6*gapY
        var baseLeft = tableLeft + 5*gapX

        switch (layoutState) {
        default:
        case 0:
            tableTop = 40
            tableLeft = 30 + 2*gapX
            baseTop = tableTop + 6*gapY
            baseLeft = tableLeft - 2*gapX
            break
        case 1:
            // handled by default values
            break
        case 2:
            tableTop = 20
            tableLeft = 60 + 2*gapX
            baseTop = tableTop + 2.6*gapY
            baseLeft = tableLeft - 2*gapX
            break
        case 3:
            tableTop = 20
            tableLeft = 60
            baseTop = tableTop + 2.6*gapY
            baseLeft = tableLeft + 9*gapX
            break
        }

        var stackCounter = 1
        oneStack(stacks[stackCounter], baseLeft, baseTop, 0, true)
        stackCounter++

        if (portrait) {
            oneStack(stacks[stackCounter], baseLeft, baseTop - 6*gapY, 0, true)
        } else {
            oneStack(stacks[stackCounter], baseLeft, baseTop - 2*gapY, 0, true)
        }

        stacks[stackCounter].customTextLocation = 1

        for (var i=0; i<4; ++i) {
            for (var j=0; j<8; ++j) {
                stackCounter++
                if (portrait) {
                    oneStack(stacks[stackCounter], tableLeft+i*gapX, tableTop+j*gapY, 0, true)
                } else {
                    oneStack(stacks[stackCounter], tableLeft+j*gapX, tableTop+(3-i)*gapY, 0, true)
                }
            }
        }


        solitairelayout.stackCount = stackCounter+1

        solitairelayout.setStatusTextPos(baseLeft - gapX + 25, baseTop - 30);
        solitairelayout.setCascadeSizeInPercent(0)
        solitairelayout.setFaceDownCascadeSizeInPercent(0)

        stacks[0].visible = false
        // hide all the rest
        for (var i=stackCounter+1; i<52; ++i) {
            stacks[i].visible = false
            stacks[i].showStack = false
        }

    }
}
