import QtQuick 1.0

Item {
    anchors.fill: parent

    property bool portrait: height > width
    property int layoutState: portrait ? (solitairelayout.leftHanded ? 0 : 1) : (solitairelayout.leftHanded ? 2 : 3)
    // 0: portrait left to right
    // 1: portrait right to left
    // 2: landscape left to right
    // 3: landscape right to left

    function oneStack(stack, x, y, cascade, showEmptyStack){
        stack.visible = true
        stack.showStack = showEmptyStack
        stack.x = x
        stack.y = y
        stack.cascadeType = cascade
    }

    function layoutStacks(stacks) {

        var gapX = solitairelayout.cardGapWidth;
        var gapY = solitairelayout.cardGapHeight;
        var cardWidth = solitairelayout.cardWidth;

        var handTop = 15;
        var handLeft = Math.floor((width-6*gapX-cardWidth)/2);
        var flipLeft = handLeft + gapX;
        var faceUpCascadeSize = 40;
        var faceDownCascadeSize = 15;
        var acesLeft = handLeft+3*gapX;
        var tableLeft = handLeft;

        switch (layoutState) {
        default:
        case 0:
            // handled by default values
            break
        case 1:
            acesLeft = handLeft
            handLeft = acesLeft+6*gapX
            flipLeft = handLeft-gapX
            tableLeft = acesLeft
            break
        case 2:
            gapX = gapX * 1.6
            handLeft = Math.floor((width-6*gapX-cardWidth)/2);
            flipLeft = handLeft + gapX;
            acesLeft = handLeft+3*gapX;
            tableLeft = handLeft;
            faceUpCascadeSize = 27;
            faceDownCascadeSize = 6;
            break
        case 3:
            gapX = gapX * 1.6
            handLeft = Math.floor((width-6*gapX-cardWidth)/2);
            acesLeft = handLeft
            handLeft = acesLeft+6*gapX
            flipLeft = handLeft-gapX
            tableLeft = acesLeft
            faceUpCascadeSize = 27;
            faceDownCascadeSize = 6;
            break
        }

        var stackCounter = 1
        oneStack(stacks[stackCounter], handLeft, handTop, 0, true)
        stackCounter++

        oneStack(stacks[stackCounter], flipLeft, handTop, solitairelayout.leftHanded ? 3 : 5, true)
        stackCounter++

        // ace stacks
        for (var i=0; i<4; ++i) {
            oneStack(stacks[stackCounter], acesLeft+i*gapX, handTop, 0, true)
            stackCounter++
        }

        // table stacks
        for (var i=0; i<7; ++i) {
            oneStack(stacks[stackCounter], tableLeft+i*gapX, handTop+gapY, 1, true)
            stackCounter++
        }
        solitairelayout.setCascadeSizeInPercent(faceUpCascadeSize)
        solitairelayout.setFaceDownCascadeSizeInPercent(faceDownCascadeSize)

        solitairelayout.stackCount = stackCounter

        stacks[0].visible = false
        // hide all the rest
        for (var i=stackCounter; i<52; ++i) {
            stacks[i].visible = false
            stacks[i].showStack = false
        }

    }
}
