import QtQuick 1.0

Item {
    anchors.fill: parent

    property bool portrait: height > width
    property int layoutState: portrait ? (solitairelayout.leftHanded ? 0 : 1) : (solitairelayout.leftHanded ? 2 : 3)
    // 0: portrait left to right
    // 1: portrait right to left
    // 2: landscape left to right
    // 3: landscape right to left

    function oneStack(stack, x, y, cascade, showEmptyStack){
        stack.visible = true
        stack.showStack = showEmptyStack
        stack.x = x
        stack.y = y
        stack.cascadeType = cascade
    }


    function layoutStacks(stacks) {

        var gapX = solitairelayout.cardGapWidth;
        var gapY = solitairelayout.cardHeight+3;
        var faceUpCascadeSize = 25;

        var baseTop = 10;
        var baseLeft = Math.floor((width-gapX*4)/2);
        var tableTop = Math.floor(solitairelayout.cardHeight*faceUpCascadeSize/100)*13+2*gapY;
        var tableLeft = Math.floor((width-gapX*5)/2);
        var handTop = tableTop + gapY*3;
        var handLeft = Math.floor((width-gapX*2)/2);

        if (!portrait) {
            // landscape
            baseTop = 10;
            tableTop = baseTop;
            tableLeft = Math.floor((width-gapX*11)/2);;
            baseLeft = tableLeft + gapY*6;
            handTop = tableTop + gapY*3;
            handLeft = Math.floor((width-gapX*2)/2);
            faceUpCascadeSize = 25;

        }

        var stackCounter = 1

        if (solitairelayout.leftHanded) {
            oneStack(stacks[stackCounter], handLeft, handTop, 0, true)
            stackCounter++
            oneStack(stacks[stackCounter], handLeft+gapX, handTop, 0, true)
            // help stack
            stackCounter++
            oneStack(stacks[stackCounter], tableLeft, tableTop, 0, true)
        } else {
            oneStack(stacks[stackCounter], handLeft+gapX, handTop, 0, true)
            stackCounter++
            oneStack(stacks[stackCounter], handLeft, handTop, 0, true)
            // help stack
            stackCounter++
            oneStack(stacks[stackCounter], tableLeft+4*gapX, tableTop, 0, true)
        }


        for (var j=0; j<2; ++j) {
            for (var i=0; i<4; ++i) {
                stackCounter++
                if (solitairelayout.leftHanded) {
                    oneStack(stacks[stackCounter], tableLeft + (i+1)*gapX, tableTop + j*gapY, 0, true)
                } else {
                    oneStack(stacks[stackCounter], tableLeft + i*gapX, tableTop + j*gapY, 0, true)
                }
            }
        }

        // base stacks
        for (var i=0; i<4; ++i) {
            stackCounter++
            oneStack(stacks[stackCounter], baseLeft + i*gapX, baseTop, 1, true)
        }

        solitairelayout.stackCount = stackCounter+1
        solitairelayout.setCascadeSizeInPercent(faceUpCascadeSize)
        solitairelayout.setFaceDownCascadeSizeInPercent(0)

        stacks[0].visible = false
        // hide all the rest
        for (var i=stackCounter+1; i<52; ++i) {
            stacks[i].visible = false
            stacks[i].showStack = false
        }

    }
}
