import QtQuick 1.0

Item {
    anchors.fill: parent

    property bool portrait: height > width
    property int layoutState: portrait ? (solitairelayout.leftHanded ? 0 : 1) : (solitairelayout.leftHanded ? 2 : 3)
    // 0: portrait left to right
    // 1: portrait right to left
    // 2: landscape left to right
    // 3: landscape right to left

    function oneStack(stack, x, y, cascade, showEmptyStack){
        stack.visible = true
        stack.showStack = showEmptyStack
        stack.x = x
        stack.y = y
        stack.cascadeType = cascade
    }

    function layoutStacks(stacks) {

        var gapX = solitairelayout.cardGapWidth;
        var gapY = solitairelayout.cardHeight+5;
        var handTop = Math.floor((height-9*gapY)/2);
        var handLeft = Math.floor((width-7*gapX)/2);
        var split = 7;
        var faceUpCascadeSize = 30;
        var faceDownCascadeSize = 15;


        if (!portrait) {
            // landscape
            split = 3;
            handTop = 5;
            faceUpCascadeSize = 30;
            faceDownCascadeSize = 8;
            if (solitairelayout.leftHanded) {
                handLeft = gapX;
            } else {
                handLeft = width - 8*gapX;
            }
        }

        var stackCounter = 1
        if (solitairelayout.leftHanded) {
            oneStack(stacks[stackCounter], handLeft, handTop, 0, true)
            stackCounter++

            oneStack(stacks[stackCounter], handLeft + gapX, handTop, 0, true)
            stackCounter++

            // ace stacks
            for (var i=0; i<4; ++i) {
                oneStack(stacks[stackCounter], handLeft+(i+3)*gapX, handTop, 0, true)
                stackCounter++
            }
        } else {
            oneStack(stacks[stackCounter], handLeft + 6*gapX, handTop, 0, true)
            stackCounter++

            oneStack(stacks[stackCounter], handLeft + 5*gapX, handTop, 0, true)
            stackCounter++

            // ace stacks
            for (var i=0; i<4; ++i) {
                oneStack(stacks[stackCounter], handLeft+i*gapX, handTop, 0, true)
                stackCounter++
            }
        }

        // table stacks
        var tableStackLeft = handLeft
        var tableStackCascade = 2
        if (!solitairelayout.leftHanded) {
            tableStackLeft = handLeft + 6*gapX
            tableStackCascade = 4
        }
        var tableStackGap = (portrait ? 10 : 0) + gapY
        var tableStackY = handTop+tableStackGap
        for (var i=0; i<7; ++i) {
            oneStack(stacks[stackCounter], tableStackLeft, tableStackY, tableStackCascade, true)
            if (i == split){
                if (solitairelayout.leftHanded) {
                    tableStackLeft = handLeft + 5*gapX
                } else {
                    tableStackLeft = handLeft + gapX
                }

                tableStackY = handTop+tableStackGap
            } else {
                tableStackY += gapY
            }
            stackCounter++
        }
        solitairelayout.setCascadeSizeInPercent(faceUpCascadeSize)
        solitairelayout.setFaceDownCascadeSizeInPercent(faceDownCascadeSize)

        solitairelayout.stackCount = stackCounter

        stacks[0].visible = false
        // hide all the rest
        for (var i=stackCounter; i<52; ++i) {
            stacks[i].visible = false
            stacks[i].showStack = false
        }

    }
}
