import QtQuick 1.0

Item {
    anchors.fill: parent

    property bool portrait: height > width
    property int layoutState: portrait ? (solitairelayout.leftHanded ? 0 : 1) : (solitairelayout.leftHanded ? 2 : 3)
    // 0: portrait left to right
    // 1: portrait right to left
    // 2: landscape left to right
    // 3: landscape right to left

    function oneStack(stack, x, y, cascade, showEmptyStack){
        stack.visible = true
        stack.showStack = showEmptyStack
        stack.x = x
        stack.y = y
        stack.cascadeType = cascade
    }

    function layoutStacks(stacks) {

        var gapX = solitairelayout.cardGapWidth;
        var gapY = solitairelayout.cardGapHeight;
        var cardWidth = solitairelayout.cardWidth;
        var handTop = 60;
        var handLeft = Math.floor((width-6*gapX-cardWidth)/2);
        var tableTop = handTop+1.5*gapY;
        var tableLeft = handLeft + gapX;
        var baseTop = handTop;
        var baseLeft = handLeft+3*gapX;
        var statusTextTop = handTop - 45;
        var statusTextLeft = handLeft;
        var faceUpCascadeSize = 30;
        var faceDownCascadeSize = 15;

        switch (layoutState) {
        default:
        case 0:
            // handled by default values
            break
        case 1:
            handLeft = handLeft + 6*gapX
            baseLeft = handLeft - 6*gapX;
            tableLeft = handLeft - gapX;
            statusTextLeft = baseLeft
            break
        case 2:
            handLeft = Math.floor((width-8*gapX-cardWidth)/2);
            tableTop = handTop+gapY;
            tableLeft = handLeft;
            baseLeft = handLeft+5*gapX;
            faceUpCascadeSize = 20;
            faceDownCascadeSize = 8;
            statusTextTop = handTop - 22;
            statusTextLeft = handLeft
            break
        case 3:
            baseLeft = Math.floor((width-8*gapX-cardWidth)/2);
            handLeft = baseLeft + 9*gapX;
            tableTop = handTop+gapY;
            tableLeft = handLeft - 3*gapX;
            faceUpCascadeSize = 20;
            faceDownCascadeSize = 8;
            statusTextTop = handTop - 22;
            statusTextLeft = tableLeft
            break
        }

        var stackCounter = 1
        oneStack(stacks[stackCounter], handLeft, handTop, 0, true)
        stackCounter++

        if (solitairelayout.leftHanded) {
            oneStack(stacks[stackCounter], handLeft + gapX, handTop, 0, true)
            stackCounter++
        } else {
            oneStack(stacks[stackCounter], handLeft - gapX, handTop, 0, true)
            stackCounter++
        }

        // base stacks
        for (var i=0; i<4; ++i) {
            oneStack(stacks[stackCounter], baseLeft + i*gapX, baseTop, 1, true)
            stacks[stackCounter].customTextLocation = 1
//            stacks[stackCounter].customText = i+1;
            stackCounter++
        }

        // table stacks
        for (var i=0; i<4; ++i) {
            if (portrait) {
                oneStack(stacks[stackCounter], tableLeft, tableTop + i*gapY, 0, true)
            } else {
                oneStack(stacks[stackCounter], tableLeft + i*gapX, tableTop, 0, true)
            }

            stackCounter++
        }
        solitairelayout.setCascadeSizeInPercent(faceUpCascadeSize)
        solitairelayout.setFaceDownCascadeSizeInPercent(faceDownCascadeSize)
        solitairelayout.setStatusTextPos(statusTextLeft, statusTextTop);

        solitairelayout.stackCount = stackCounter

        stacks[0].visible = false
        // hide all the rest
        for (var i=stackCounter; i<52; ++i) {
            stacks[i].visible = false
            stacks[i].showStack = false
        }

    }
}
